<!doctype html>
<html <?php language_attributes(); ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta name="viewport" content="width=device-width, initial-scale=1" />
<!-- Favicon-->
<?php 
	$favicon = noo_get_image_option('noo_custom_favicon', '');
	if ($favicon != ''): ?>
	<link rel="shortcut icon" href="<?php echo esc_url($favicon); ?>" />
<?php
endif; ?>
<!--[if lt IE 9]>
<script src="<?php echo NOO_FRAMEWORK_URI . '/vendor/respond.min.js'; ?>"></script>
<![endif]-->
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<div class="site">

	<?php
	$rev_slider_pos = home_slider_position(); ?>
	<?php
		if($rev_slider_pos == 'above') {
			noo_get_layout( 'slider-revolution');
		}
	?>
	<header class="noo-header <?php noo_header_class(); ?>" id="noo-header" role="banner">
		<?php noo_get_layout('topbar'); ?>
		<?php noo_get_layout('navbar'); ?>
	</header>

	<?php
		if($rev_slider_pos == 'below') {
			noo_get_layout( 'slider-revolution');
		}
	?>


	
<?php
list($heading, $archive_title, $archive_desc) = get_page_heading();
if( ! empty($heading) ) :
	$heading_image = get_page_heading_image();
?>
	<?php if( noo_get_option( 'noo_page_heading', true ) ) : ?>
		<?php if(!noo_get_post_meta(get_the_ID(), '_noo_wp_page_hide_page_title', false) ) { ?>
			<?php if( !empty( $heading_image ) ) : ?>
				<header class="noo-page-heading heading-bg-image" style="background-image: url('<?php echo esc_url($heading_image); ?>');" >
			<?php else : ?>
				<header class="noo-page-heading">
			<?php endif; ?>
				<div class="container-boxed max">
					<div class="page-heading-info ">
						<h1 class="page-title"><span class="nth-word-first">Le</span> blog du lodge</h1>
					</div>
					<div class="noo-page-breadcrumb">
						<ul class="breadcrumb"><li><a href="../blog">Accueil du blog</a></li><li class="active"><span><?php the_title(); ?></span></li></ul>
					</div>
				</div><!-- /.container-boxed -->
			</header>
		<?php } ?>
	<?php endif; ?>
<?php endif; ?>	   

<div class="container-boxed max offset">
	<div class="row">
		<div class="<?php noo_main_class(); ?>" role="main">
			<?php while ( have_posts() ) : the_post(); ?>
				<?php noo_get_layout( 'post', get_post_format()); ?>
				<?php wp_link_pages( array( 'before' => '<div class="page-links">' . __( 'Pages:', 'noo' ), 'after' => '</div>' ) ); ?>
				<?php noo_post_nav();?>
				<?php if ( comments_open() ) : ?>
					<?php comments_template( '', true ); ?>
				<?php endif; ?>
			<?php endwhile; ?>
		</div>
		<?php get_sidebar(); ?>
	</div> <!-- /.row -->
</div> <!-- /.container-boxed.max.offset -->
<?php get_footer(); ?>